@@ -54,6 +54,7 @@
 #include "filtering.h"
 #include "prefs_actions.h"
 #include "hooks.h"
+#include "passwordstore.h"
 
 enum {
 	ACCOUNT_IS_DEFAULT,
@@ -375,6 +376,9 @@ GList *account_get_list(void)
 
 void account_edit_focus(void)
 {
+	if (edit_account.window == NULL) {
+		return;
+	}
 	manage_window_set_transient(GTK_WINDOW(edit_account.window));
 	gtk_widget_grab_focus(edit_account.close_btn);
 	gtk_widget_show(edit_account.window);
@@ -1100,6 +1104,10 @@ static void account_delete(GtkWidget *widget, gpointer data)
 				GINT_TO_POINTER(ac_prefs->account_id));
 	}
 
+	gchar *uid = g_strdup_printf("%d", ac_prefs->account_id);
+	passwd_store_delete_block(PWS_ACCOUNT, uid);
+	g_free(uid);
+
 	debug_print("Removing filter rules relative to this account...\n");
 	for(cur = filtering_rules ; cur != NULL ;) {
 		FilteringProp * prop = (FilteringProp *) cur->data;
