@@ -710,8 +710,8 @@ void gtkut_widget_set_app_icon(GtkWidget *widget)
 	cm_return_if_fail(gtk_widget_get_window(widget) != NULL);
 	if (!icon_list) {
 		GdkPixbuf *icon = NULL, *big_icon = NULL;
-		stock_pixbuf_gdk(widget, STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
-		stock_pixbuf_gdk(widget, STOCK_PIXMAP_CLAWS_MAIL_LOGO, &big_icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_LOGO, &big_icon);
 		if (icon)
 			icon_list = g_list_append(icon_list, icon);
 		if (big_icon)
@@ -729,8 +729,8 @@ void gtkut_widget_set_composer_icon(GtkWidget *widget)
 	cm_return_if_fail(gtk_widget_get_window(widget) != NULL);
 	if (!icon_list) {
 		GdkPixbuf *icon = NULL, *big_icon = NULL;
-		stock_pixbuf_gdk(widget, STOCK_PIXMAP_MAIL_COMPOSE, &icon);
-		stock_pixbuf_gdk(widget, STOCK_PIXMAP_MAIL_COMPOSE_LOGO, &big_icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_MAIL_COMPOSE, &icon);
+		stock_pixbuf_gdk(STOCK_PIXMAP_MAIL_COMPOSE_LOGO, &big_icon);
 		if (icon)
 			icon_list = g_list_append(icon_list, icon);
 		if (big_icon)
@@ -1061,13 +1061,13 @@ gboolean get_tag_range(GtkTextIter *iter,
 
 	_end_iter = *iter;
 	if (!gtk_text_iter_forward_to_tag_toggle(&_end_iter, tag)) {
-		debug_print("Can't find end");
+		debug_print("Can't find end.\n");
 		return FALSE;
 	}
 
 	_start_iter = _end_iter;
 	if (!gtk_text_iter_backward_to_tag_toggle(&_start_iter, tag)) {
-		debug_print("Can't find start.");
+		debug_print("Can't find start.\n");
 		return FALSE;
 	}
 
