@@ -183,9 +183,8 @@ static void new_folder_cb(GtkAction *action, gpointer data)
 	gchar *p;
 	gchar separator = '/';
 	
-	if (!folderview->selected) return;
+	if ((item = folderview_get_selected_item(folderview)) == NULL) return;
 
-	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
 	cm_return_if_fail(item->folder != NULL);
 	cm_return_if_fail(item->folder->account != NULL);
@@ -340,15 +339,14 @@ static void copy_folder_cb(GtkAction *action, gpointer data)
 static void delete_folder_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
-	FolderItem *item;
+	FolderItem *item, *opened;
 	gchar *message, *name;
 	AlertValue avalue;
 	gchar *old_id;
 
-	if (!folderview->selected) return;
+	if ((item = folderview_get_selected_item(folderview)) == NULL) return;
+	opened = folderview_get_opened_item(folderview);
 
-	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
 	cm_return_if_fail(item->path != NULL);
 	cm_return_if_fail(item->folder != NULL);
@@ -367,12 +365,10 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 
 	old_id = folder_item_get_identifier(item);
 
-	if (folderview->opened == folderview->selected ||
-	    gtk_cmctree_is_ancestor(ctree,
-				  folderview->selected,
-				  folderview->opened)) {
+	if (item == opened ||
+			folder_is_child_of(item, opened)) {
 		summary_clear_all(folderview->summaryview);
-		folderview->opened = NULL;
+		folderview_close_opened(folderview, TRUE);
 	}
 
 	if (item->folder->klass->remove_folder(item->folder, item) < 0) {
@@ -482,17 +478,13 @@ static gboolean imap_gtk_subscribe_func(GNode *node, gpointer data)
 
 static void subscribe_cb_full(FolderView *folderview, guint action)
 {
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	gchar *message, *name;
 	AlertValue avalue;
 	GtkWidget *rec_chk;
 	gboolean recurse = FALSE;
 
-	if (!folderview->selected) return;
-
-	item = folderview_get_selected_item(folderview);
-	cm_return_if_fail(item != NULL);
+	if ((item = folderview_get_selected_item(folderview)) == NULL) return;
 	cm_return_if_fail(item->folder != NULL);
 
 	name = trim_string(item->name, 32);
@@ -577,14 +569,13 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
 	
-	
+	FolderItem *opened = folderview_get_opened_item(folderview);
+	FolderItem *selected = folderview_get_selected_item(folderview);
 	if (!action) {
-		if (folderview->opened == folderview->selected ||
-		    gtk_cmctree_is_ancestor(ctree,
-					  folderview->selected,
-					  folderview->opened)) {
+		if (opened == selected ||
+				folder_is_child_of(selected, opened)) {
 			summary_clear_all(folderview->summaryview);
-			folderview->opened = NULL;
+			folderview_close_opened(folderview, TRUE);
 		}
 	}
 
@@ -612,20 +603,18 @@ static void unsubscribe_cb(GtkAction *action, gpointer data)
 static void subscribed_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item = folderview_get_selected_item(folderview);
+	FolderItem *opened = folderview_get_opened_item(folderview);
 	
 	if (!item || !item->folder || !item->folder->account)
 		return;
 	if (item->folder->account->imap_subsonly == gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 		return;
 
-	if (folderview->opened == folderview->selected ||
-	    gtk_cmctree_is_ancestor(ctree,
-				  folderview->selected,
-				  folderview->opened)) {
+	if (opened == item ||
+			folder_is_child_of(item, opened)) {
 		summary_clear_all(folderview->summaryview);
-		folderview->opened = NULL;
+		folderview_close_opened(folderview, TRUE);
 	}
 
 	item->folder->account->imap_subsonly = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
@@ -637,8 +626,6 @@ static void download_cb(GtkAction *action, gpointer data)
 	FolderView *folderview = (FolderView *)data;
 	FolderItem *item;
 
-	if (!folderview->selected) return;
-
-	item = folderview_get_selected_item(folderview);
+	if ((item = folderview_get_selected_item(folderview)) == NULL) return
 	imap_gtk_synchronise(item, 0);
 }
