@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2015 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,6 +79,7 @@
 #include "prefs_fonts.h"
 #include "prefs_image_viewer.h"
 #include "prefs_message.h"
+#include "prefs_migration.h"
 #include "prefs_receive.h"
 #include "prefs_msg_colors.h"
 #include "prefs_quote.h"
@@ -127,6 +127,7 @@
 #include "quicksearch.h"
 #include "advsearch.h"
 #include "avatars.h"
+#include "passwordstore.h"
 
 #ifdef HAVE_LIBETPAN
 #include "imap-thread.h"
@@ -202,6 +203,7 @@ static struct RemoteCmd {
 	const gchar *subscribe_uri;
 	const gchar *target;
 	gboolean debug;
+	const gchar *geometry;
 } cmd;
 
 SessionStats session_stats;
@@ -461,8 +463,8 @@ static int migrate_common_rc(const gchar *old_rc, const gchar *new_rc)
 		if (strncmp(buf, old_plugin_path, strlen(old_plugin_path))) {
 			err |= (fputs(buf, newfp) == EOF);
 		} else {
-			debug_print("->replacing %s", buf);
-			debug_print("  with %s%s", new_plugin_path, buf+strlen(old_plugin_path));
+			debug_print("->replacing %s\n", buf);
+			debug_print("  with %s%s\n", new_plugin_path, buf+strlen(old_plugin_path));
 			err |= (fputs(new_plugin_path, newfp) == EOF);
 			err |= (fputs(buf+strlen(old_plugin_path), newfp) == EOF);
 		}
@@ -1277,7 +1279,7 @@ int main(int argc, char *argv[])
 	}
 #endif
 	gtkut_widget_init();
-	stock_pixbuf_gdk(NULL, STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
+	stock_pixbuf_gdk(STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
 	gtk_window_set_default_icon(icon);
 
 	folderview_initialize();
@@ -1298,9 +1300,10 @@ int main(int argc, char *argv[])
 	manage_window_focus_in(mainwin->window, NULL, NULL);
 	folderview = mainwin->folderview;
 
-	gtk_cmclist_freeze(GTK_CMCLIST(mainwin->folderview->ctree));
+	folderview_freeze(mainwin->folderview);
 	folder_item_update_freeze();
 
+	passwd_store_read_config();
 	prefs_account_init();
 	account_read_config_all();
 
@@ -1456,9 +1459,19 @@ int main(int argc, char *argv[])
 	}
 
 	if (never_ran) {
+		prefs_common_get_prefs()->config_version = CLAWS_CONFIG_VERSION;
 		prefs_common_write_config();
 	 	plugin_load_standard_plugins ();
+	} else {
+		if (prefs_update_config_version() < 0) {
+			exit_claws(mainwin);
+#ifdef G_OS_WIN32
+			win32_close_log();
+#endif
+			exit(0);
+		}
 	}
+
 	/* if not crashed, show window now */
 	if (!mainwin_shown) {
 		/* apart if something told not to show */
@@ -1466,6 +1479,19 @@ int main(int argc, char *argv[])
 			main_window_popup(mainwin);
 	}
 
+	if (cmd.geometry != NULL) {
+		if (!gtk_window_parse_geometry(GTK_WINDOW(mainwin->window), cmd.geometry))
+			g_warning("failed to parse geometry '%s'", cmd.geometry);
+		else {
+			int width, height;
+
+			if (sscanf(cmd.geometry, "%ux%u+", &width, &height) == 2)
+				gtk_window_resize(GTK_WINDOW(mainwin->window), width, height);
+			else
+				g_warning("failed to parse geometry's width/height");
+		}
+	}
+
 	if (!folder_have_mailbox()) {
 		prefs_destroy_cache();
 		main_window_cursor_normal(mainwin);
@@ -1499,7 +1525,7 @@ int main(int argc, char *argv[])
 #endif
 
 	folder_item_update_thaw();
-	gtk_cmclist_thaw(GTK_CMCLIST(mainwin->folderview->ctree));
+	folderview_thaw(mainwin->folderview);
 	main_window_cursor_normal(mainwin);
 
 	if (!cmd.target && prefs_common.goto_last_folder_on_startup &&
@@ -1517,8 +1543,8 @@ int main(int argc, char *argv[])
 	} else if (cmd.receive && !cmd.target) {
 		start_done = FALSE;
 		g_timeout_add(1000, defer_check, NULL);
-	} 
-	gtk_widget_grab_focus(folderview->ctree);
+	}
+	folderview_grab_focus(folderview);
 
 	if (cmd.compose) {
 		open_compose_new(cmd.compose_mailto, cmd.attach_files);
@@ -1596,6 +1622,7 @@ static void exit_claws(MainWindow *mainwin)
 {
 	gchar *filename;
 	gboolean have_connectivity;
+	FolderItem *item;
 
 	sc_exiting = TRUE;
 
@@ -1608,18 +1635,11 @@ static void exit_claws(MainWindow *mainwin)
 #endif
 
 	/* save prefs for opened folder */
-	if(mainwin->folderview->opened) {
-		FolderItem *item;
-
-		item = gtk_cmctree_node_get_row_data(
-			GTK_CMCTREE(mainwin->folderview->ctree),
-			mainwin->folderview->opened);
-		if (item) {
-			summary_save_prefs_to_folderitem(
-				mainwin->folderview->summaryview, item);
-			prefs_common.last_opened_folder = 
-				folder_item_get_identifier(item);
-		}
+	if((item = folderview_get_opened_item(mainwin->folderview)) != NULL) {
+		summary_save_prefs_to_folderitem(
+			mainwin->summaryview, item);
+		prefs_common.last_opened_folder =
+			folder_item_get_identifier(item);
 	}
 
 	/* save all state before exiting */
@@ -1631,6 +1651,7 @@ static void exit_claws(MainWindow *mainwin)
 
 	prefs_common_write_config();
 	account_write_config_all();
+	passwd_store_write_config();
 #ifndef USE_ALT_ADDRBOOK
 	addressbook_export_to_file();
 #endif
@@ -1947,6 +1968,8 @@ static void parse_cmd_opt(int argc, char *argv[])
 			g_print("%s\n", _("  --config-dir           output configuration directory"));
 			g_print("%s\n", _("  --alternate-config-dir [dir]\n"
 			                  "                         use specified configuration directory"));
+			g_print("%s\n", _("  --geometry -geometry WxH+X+Y\n"
+					  "                         set geometry for main window"));
 
 			g_free(base);
 			exit(1);
@@ -1959,6 +1982,9 @@ static void parse_cmd_opt(int argc, char *argv[])
 			exit(0);
 		} else if (!strncmp(argv[i], "--alternate-config-dir", sizeof "--alternate-config-dir" - 1) && i+1 < argc) {
 			set_rc_dir(argv[i+1]);
+		} else if (!strncmp(argv[i], "--geometry", sizeof "--geometry" - 1)
+			  || !strncmp(argv[i], "-geometry", sizeof "-geometry" - 1)) {
+			cmd.geometry = (i+1 < argc)? argv[i+1]: NULL;
 		} else if (!strncmp(argv[i], "--exit", 6) ||
 			   !strncmp(argv[i], "--quit", 6) ||
 			   !strncmp(argv[i], "-q", 2)) {
