@@ -48,6 +48,7 @@
 #include "statusbar.h"
 #include "codeconv.h"
 #include "utils.h"
+#include "passwordstore.h"
 #include "prefs_common.h"
 #include "prefs_account.h"
 #include "inputdialog.h"
@@ -404,12 +405,12 @@ static Session *news_session_new_for_folder(Folder *folder)
 		userid = ac->userid;
 		if (password_get(userid, ac->nntp_server, "nntp", port, &passwd)) {
 			/* NOP */;
-		} else if (ac->passwd && ac->passwd[0])
-			passwd = g_strdup(ac->passwd);
-		else
+		} else if ((passwd = passwd_store_get_account(ac->account_id,
+					PWS_ACCOUNT_RECV)) == NULL) {
 			passwd = input_dialog_query_password_keep(ac->nntp_server,
 								  userid,
 								  &(ac->session_passwd));
+		}
 	}
 
 	if (session != NULL)
@@ -1445,7 +1446,7 @@ static void warn_etpan(void)
 			_("You have one or more News accounts "
 			  "defined. However this version of "
 			  "Claws Mail has been built without "
-			  "News support; your News account(s) are "
+			  "News support; your News accounts are "
 			  "disabled.\n\n"
 			  "You probably need to "
 			  "install libetpan and recompile "
