@@ -299,7 +299,7 @@ void notification_foldercheck_write_array(void)
 
 /* Read selections from a common xml-file. Called when loading the plugin.
  * Returns TRUE if data has been read, FALSE if no data is available
- * or an error occured.
+ * or an error occurred.
  * This is analog to folder.h::folder_read_list. */
 gboolean notification_foldercheck_read_array(void)
 {
@@ -502,13 +502,13 @@ static void foldercheck_create_window(SpecificFolderArrayEntry *entry)
 
   /* pixbufs */
   if(!folder_pixbuf)
-    stock_pixbuf_gdk(scrolledwin, STOCK_PIXMAP_DIR_CLOSE,
+    stock_pixbuf_gdk(STOCK_PIXMAP_DIR_CLOSE,
 		     &folder_pixbuf);
   if(!folderopen_pixbuf)
-    stock_pixbuf_gdk(scrolledwin, STOCK_PIXMAP_DIR_OPEN,
+    stock_pixbuf_gdk(STOCK_PIXMAP_DIR_OPEN,
 		     &folderopen_pixbuf);
   if(!foldernoselect_pixbuf)
-    stock_pixbuf_gdk(scrolledwin, STOCK_PIXMAP_DIR_NOSELECT,
+    stock_pixbuf_gdk(STOCK_PIXMAP_DIR_NOSELECT,
 		     &foldernoselect_pixbuf);
 
   /* Tree store */
