@@ -267,6 +267,7 @@ guint feed_update(Feed *feed, time_t last_update)
 	feed_ctx->parser = XML_ParserCreate(NULL);
 	feed_ctx->depth = 0;
 	feed_ctx->str = NULL;
+	feed_ctx->xhtml_str = NULL;
 	feed_ctx->feed = feed;
 	feed_ctx->location = 0;
 	feed_ctx->curitem = NULL;
@@ -348,6 +349,10 @@ cleanup:
 	XML_ParserFree(feed_ctx->parser);
 	g_free(feed_ctx->name);
 	g_free(feed_ctx->mail);
+	if (feed_ctx->str != NULL)
+		g_string_free(feed_ctx->str, TRUE);
+	if (feed_ctx->xhtml_str != NULL)
+		g_string_free(feed_ctx->xhtml_str, TRUE);
 	g_free(feed_ctx);
 
 	return response_code;
