@@ -152,7 +152,7 @@ void rssyl_init(void)
 	else
 		rssyl_update_format();
 
-	prefs_toolbar_register_plugin_item(TOOLBAR_MAIN, "RSSyl", _("Refresh all feeds"), rssyl_toolbar_cb_refresh_all_feeds, NULL);
+	prefs_toolbar_register_plugin_item(TOOLBAR_MAIN, PLUGIN_NAME, _("Refresh all feeds"), rssyl_toolbar_cb_refresh_all_feeds, NULL);
 
 	if( rssyl_prefs_get()->refresh_on_startup &&
 			claws_is_starting() )
@@ -163,7 +163,7 @@ void rssyl_done(void)
 {
 	rssyl_opml_export();
 
-	prefs_toolbar_unregister_plugin_item(TOOLBAR_MAIN, "RSSyl", _("Refresh all feeds"));
+	prefs_toolbar_unregister_plugin_item(TOOLBAR_MAIN, PLUGIN_NAME, _("Refresh all feeds"));
 
 	rssyl_prefs_done();
 	rssyl_gtk_done();
@@ -286,12 +286,14 @@ static void rssyl_item_set_xml(Folder *folder, FolderItem *item, XMLTag *tag)
 			g_free(ritem->auth->username);
 			ritem->auth->username = g_strdup(attr->value);
 		}
-		/* (str) Auth pass */
+		/* (str) Auth pass - save directly to password store */
 		if (!strcmp(attr->name, "auth_pass")) {
 			gsize len = 0;
 			guchar *pwd = g_base64_decode(attr->value, &len);
-			g_free(ritem->auth->password);
-			ritem->auth->password = (gchar *)pwd;
+			memset(attr->value, 0, strlen(attr->value));
+			rssyl_passwd_set(ritem, (gchar *)pwd);
+			memset(pwd, 0, strlen(pwd));
+			g_free(pwd);
 		}
 		/* (str) Official title */
 		if( !strcmp(attr->name, "official_title")) {
@@ -346,12 +348,6 @@ static XMLTag *rssyl_item_get_xml(Folder *folder, FolderItem *item)
 	/* (str) Auth user */
 	if (ri->auth->username != NULL)
 		xml_tag_add_attr(tag, xml_attr_new("auth_user", ri->auth->username));
-	/* (str) Auth pass */
-	if (ri->auth->password != NULL) {
-		gchar *pwd = g_base64_encode(ri->auth->password, strlen(ri->auth->password));
-		xml_tag_add_attr(tag, xml_attr_new("auth_pass", pwd));
-		g_free(pwd);
-	}
 	/* (str) Official title */
 	if( ri->official_title != NULL )
 		xml_tag_add_attr(tag, xml_attr_new("official_title", ri->official_title));
@@ -628,6 +624,7 @@ static gint rssyl_rename_folder(Folder *folder, FolderItem *item,
 static gint rssyl_remove_folder(Folder *folder, FolderItem *item)
 {
 	gchar *path = NULL;
+	RFolderItem *ritem = (RFolderItem *)item;
 
 	g_return_val_if_fail(folder != NULL, -1);
 	g_return_val_if_fail(item != NULL, -1);
@@ -642,8 +639,11 @@ static gint rssyl_remove_folder(Folder *folder, FolderItem *item)
 		g_free(path);
 		return -1;
 	}
-
 	g_free(path);
+
+	if (ritem->url != NULL)
+		rssyl_passwd_set(ritem, NULL);
+
 	folder_item_remove(item);
 
 	return 0;
@@ -945,7 +945,7 @@ FolderClass *rssyl_folder_get_class()
 	if( rssyl_class.idstr == NULL ) {
 		rssyl_class.type = F_UNKNOWN;
 		rssyl_class.idstr = "rssyl";
-		rssyl_class.uistr = "RSSyl";
+		rssyl_class.uistr = PLUGIN_NAME;
 
 		/* Folder functions */
 		rssyl_class.new_folder = rssyl_new_folder;
