@@ -49,11 +49,13 @@ static void rssyl_gtk_prop_store(RFolderItem *ritem)
 
 	g_return_if_fail(ritem != NULL);
 	g_return_if_fail(ritem->feedprop != NULL);
+	g_return_if_fail(ritem->url != NULL);
 
 	url = (gchar *)gtk_entry_get_text(GTK_ENTRY(ritem->feedprop->url));
 
-	if( strlen(url) ) {
+	if( strlen(url) && strcmp(ritem->url, url)) {
 		if( ritem->url ) {
+			rssyl_passwd_set(ritem, NULL);
 			g_free(ritem->url);
 		}
 		ritem->url = g_strdup(url);
@@ -70,12 +72,7 @@ static void rssyl_gtk_prop_store(RFolderItem *ritem)
 	}
 
 	auth_pass = (gchar *)gtk_entry_get_text(GTK_ENTRY(ritem->feedprop->auth_password));
-	if (auth_pass != NULL) {
-		if (ritem->auth->password) {
-			g_free(ritem->auth->password);
-		}
-		ritem->auth->password = g_strdup(auth_pass);
-	}
+	rssyl_passwd_set(ritem, auth_pass);
 
 	use_default_ri = gtk_toggle_button_get_active(
 			GTK_TOGGLE_BUTTON(ritem->feedprop->default_refresh_interval));
@@ -282,8 +279,12 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 	/* Auth password */
 	feedprop->auth_password = gtk_entry_new();
 	gtk_entry_set_visibility(GTK_ENTRY(feedprop->auth_password), FALSE);
-	gtk_entry_set_text(GTK_ENTRY(feedprop->auth_password),
-			ritem->auth->password);
+	gchar *pwd = rssyl_passwd_get(ritem);
+	gtk_entry_set_text(GTK_ENTRY(feedprop->auth_password), pwd);
+	if (pwd != NULL) {
+		memset(pwd, 0, strlen(pwd));
+		g_free(pwd);
+	}
 
 	/* "Use default refresh interval" checkbutton */
 	feedprop->default_refresh_interval = gtk_check_button_new_with_mnemonic(
@@ -422,7 +423,7 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 			ritem->fetch_comments);
 	gtk_box_pack_start(GTK_BOX(hbox), feedprop->fetch_comments_max_age, FALSE, FALSE, 0);
 	/* Fetch comments max age - units label */
-	label = gtk_label_new(g_strconcat(_("day(s)"), "<small>    ",
+	label = gtk_label_new(g_strconcat(_("days"), "<small>    ",
 				_("Set to -1 to fetch all comments"), "</small>", NULL));
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
@@ -472,7 +473,7 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 			!ritem->default_refresh_interval);
 	gtk_box_pack_start(GTK_BOX(hbox), feedprop->refresh_interval, FALSE, FALSE, 0);
 	/* Refresh interval - units label */
-	label = gtk_label_new(g_strconcat(_("minute(s)"), "<small>    ",
+	label = gtk_label_new(g_strconcat(_("minutes"), "<small>    ",
 			_("Set to 0 to disable automatic refreshing for this feed"),
 			"</small>", NULL));
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
