@@ -60,6 +60,7 @@
 #include "mainwindow.h"
 #include "statusbar.h"
 #include "msgcache.h"
+#include "passwordstore.h"
 #include "timing.h"
 #include "messageview.h"
 
@@ -1053,7 +1054,7 @@ static gint vcal_remove_msg(Folder *folder, FolderItem *_item, gint num)
 	if (_item == folder->inbox)
 		vcal_remove_event(folder, msginfo);
 
-	procmsg_msginfo_free(msginfo);
+	procmsg_msginfo_free(&msginfo);
 	return 0;
 }
 
@@ -1170,31 +1171,45 @@ void vcal_folder_export(Folder *folder)
 {	
 	FolderItem *item = folder?folder->inbox:NULL;
 	gboolean need_scan = folder?vcal_scan_required(folder, item):TRUE;
+	gchar *export_pass = NULL;
+	gchar *export_freebusy_pass = NULL;
 
 	if (vcal_folder_lock_count) /* blocked */
 		return;
 	vcal_folder_lock_count++;
+	
+	export_pass = vcal_passwd_get("export");
+	export_freebusy_pass = vcal_passwd_get("export_freebusy");
+
 	if (vcal_meeting_export_calendar(vcalprefs.export_path, 
 			vcalprefs.export_user, 
-			vcalprefs.export_pass,
+			export_pass,
 			TRUE)) {
 		debug_print("exporting calendar\n");
 		if (vcalprefs.export_enable &&
 		    vcalprefs.export_command &&
 		    strlen(vcalprefs.export_command))
 			execute_command_line(
-				vcalprefs.export_command, TRUE);
+				vcalprefs.export_command, TRUE, NULL);
 	}
+	if (export_pass != NULL) {
+		memset(export_pass, 0, strlen(export_pass));
+	}
+	g_free(export_pass);
 	if (vcal_meeting_export_freebusy(vcalprefs.export_freebusy_path,
 			vcalprefs.export_freebusy_user,
-			vcalprefs.export_freebusy_pass)) {
+			export_freebusy_pass)) {
 		debug_print("exporting freebusy\n");
 		if (vcalprefs.export_freebusy_enable &&
 		    vcalprefs.export_freebusy_command &&
 		    strlen(vcalprefs.export_freebusy_command))
 			execute_command_line(
-				vcalprefs.export_freebusy_command, TRUE);
+				vcalprefs.export_freebusy_command, TRUE, NULL);
 	}
+	if (export_freebusy_pass != NULL) {
+		memset(export_freebusy_pass, 0, strlen(export_freebusy_pass));
+	}
+	g_free(export_freebusy_pass);
 	vcal_folder_lock_count--;
 	if (!need_scan && folder) {
 		vcal_set_mtime(folder, folder->inbox);
@@ -1951,8 +1966,7 @@ static void subscribe_cal_cb(GtkAction *action, gpointer data)
 static void unsubscribe_cal_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
-	FolderItem *item;
+	FolderItem *item, *opened;
 	gchar *message;
 	AlertValue avalue;
 	gchar *old_id;
@@ -1963,6 +1977,7 @@ static void unsubscribe_cal_cb(GtkAction *action, gpointer data)
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->path != NULL);
 	g_return_if_fail(item->folder != NULL);
+	opened = folderview_get_opened_item(folderview);
 
 	message = g_strdup_printf
 		(_("Do you really want to unsubscribe?"));
@@ -1976,12 +1991,10 @@ static void unsubscribe_cal_cb(GtkAction *action, gpointer data)
 
 	vcal_item_closed(item);
 
-	if (folderview->opened == folderview->selected ||
-	    gtk_cmctree_is_ancestor(ctree,
-				  folderview->selected,
-				  folderview->opened)) {
+	if (item == opened ||
+			folder_is_child_of(item, opened)) {
 		summary_clear_all(folderview->summaryview);
-		folderview->opened = NULL;
+		folderview_close_opened(folderview, TRUE);
 	}
 
 	if (item->folder->klass->remove_folder(item->folder, item) < 0) {
@@ -2417,7 +2430,7 @@ gboolean vcal_event_exists(const gchar *id)
 
 	info = folder_item_get_msginfo_by_msgid(folder->inbox, id);
 	if (info != NULL) {
-		procmsg_msginfo_free(info);
+		procmsg_msginfo_free(&info);
 		return TRUE;
 	}
 	return FALSE;
@@ -2455,7 +2468,7 @@ gboolean vcal_delete_event(const gchar *id)
 	if (info != NULL) {
 		debug_print("removing event %s\n", id);
 		vcal_remove_event(folder, info);
-		procmsg_msginfo_free(info);
+		procmsg_msginfo_free(&info);
 		folder_item_scan(folder->inbox);
 		return TRUE;
 	}
