@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto & The Claws Mail Team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -138,13 +137,12 @@ static gboolean free_func(GNode *node, gpointer data)
 	if (mimeinfo->privacy)
 		privacy_free_privacydata(mimeinfo->privacy);
 
-	g_free(mimeinfo);
-
 	return FALSE;
 }
 
-void procmime_mimeinfo_free_all(MimeInfo *mimeinfo)
+void procmime_mimeinfo_free_all(MimeInfo **mimeinfo_ptr)
 {
+	MimeInfo *mimeinfo = *mimeinfo_ptr;
 	GNode *node;
 
 	if (!mimeinfo)
@@ -154,6 +152,9 @@ void procmime_mimeinfo_free_all(MimeInfo *mimeinfo)
 	g_node_traverse(node, G_IN_ORDER, G_TRAVERSE_ALL, -1, free_func, NULL);
 
 	g_node_destroy(node);
+
+	g_free(mimeinfo);
+	*mimeinfo_ptr = NULL;
 }
 
 MimeInfo *procmime_mimeinfo_parent(MimeInfo *mimeinfo)
@@ -946,17 +947,17 @@ scan_again:
 		 * fully for non-empty parts
 		 */
 		short_scan = FALSE;
-		procmime_mimeinfo_free_all(mimeinfo);
+		procmime_mimeinfo_free_all(&mimeinfo);
 		goto scan_again;
 	} else if (!empty_ok && !short_scan) {
 		/* if full scan didn't find a non-empty part, rescan
 		 * accepting empty parts 
 		 */
 		empty_ok = TRUE;
-		procmime_mimeinfo_free_all(mimeinfo);
+		procmime_mimeinfo_free_all(&mimeinfo);
 		goto scan_again;
 	}
-	procmime_mimeinfo_free_all(mimeinfo);
+	procmime_mimeinfo_free_all(&mimeinfo);
 
 	/* outfp already unlocked at this time */
 	return outfp;
@@ -1019,7 +1020,7 @@ FILE *procmime_get_first_encrypted_text_content(MsgInfo *msginfo)
 	if (partinfo)
 		outfp = procmime_get_text_content(partinfo);
 
-	procmime_mimeinfo_free_all(mimeinfo);
+	procmime_mimeinfo_free_all(&mimeinfo);
 
 	/* outfp already unlocked at this time */
 	return outfp;
@@ -1039,7 +1040,7 @@ gboolean procmime_msginfo_is_encrypted(MsgInfo *msginfo)
 
 	partinfo = mimeinfo;
 	result = (find_encrypted_part(partinfo) != NULL);
-	procmime_mimeinfo_free_all(mimeinfo);
+	procmime_mimeinfo_free_all(&mimeinfo);
 
 	return result;
 }
@@ -1584,7 +1585,7 @@ static void procmime_parse_disposition_notification(MimeInfo *mimeinfo,
 			debug_print("%s %s in %s\n", info?"found":"didn't find", orig_msg_id, outbox->path);
 			if (info) {
 				procmsg_msginfo_set_flags(info, MSG_RETRCPT_GOT, 0);
-				procmsg_msginfo_free(info);
+				procmsg_msginfo_free(&info);
 			}
 		}
 	}
@@ -2043,7 +2044,7 @@ static int procmime_parse_mimepart(MimeInfo *parent,
 			 * this avoids DOSsing ourselves 
 			 * with enormous messages
 			 */
-			procmime_mimeinfo_free_all(mimeinfo);
+			procmime_mimeinfo_free_all(&mimeinfo);
 			return -1;			
 		}
 		g_node_append(parent->node, mimeinfo->node);
@@ -2349,7 +2350,7 @@ static void write_parameters(gpointer key, gpointer value, gpointer user_data)
 		break;
 #else
 	case ENC_AS_EXTENDED:
-		debug_print("Unhandled ENC_AS_EXTENDED.");
+		debug_print("Unhandled ENC_AS_EXTENDED.\n");
 		break;
 #endif
 	case ENC_AS_ENCWORD:
