@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2015 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -2106,7 +2106,7 @@ static void textview_show_contact_pic(TextView *textview)
 		picture = gdk_pixbuf_new_from_file(filename, &error);
 
 	if (error) {
-		debug_print("Failed to import image: \n%s",
+		debug_print("Failed to import image: %s\n",
 				error->message);
 		g_error_free(error);
 		goto bail;
@@ -3007,7 +3007,7 @@ static void open_image_cb (GtkAction *action, TextView *textview)
 		return;
 	}
 
-	execute_command_line(buf, TRUE);
+	execute_command_line(buf, TRUE, NULL);
 
 	g_free(filepath);
 	g_free(filename);
