@@ -50,6 +50,7 @@
 #endif
 #include "prefs_common.h"
 #include "combobox.h"
+#include "passwordstore.h"
 
 typedef enum
 {
@@ -756,13 +757,16 @@ static gboolean wizard_write_config(WizardWindow *wizard)
 
 	prefs_account->userid = g_strdup(
 				gtk_entry_get_text(GTK_ENTRY(wizard->recv_username)));
-	prefs_account->passwd = g_strdup(
-				gtk_entry_get_text(GTK_ENTRY(wizard->recv_password)));
-
 	prefs_account->smtp_userid = g_strdup(
 				gtk_entry_get_text(GTK_ENTRY(wizard->smtp_username)));
-	prefs_account->smtp_passwd = g_strdup(
-				gtk_entry_get_text(GTK_ENTRY(wizard->smtp_password)));
+
+	passwd_store_set_account(prefs_account->account_id, PWS_ACCOUNT_RECV,
+			gtk_entry_get_text(GTK_ENTRY(wizard->recv_password)),
+			FALSE);
+	passwd_store_set_account(prefs_account->account_id, PWS_ACCOUNT_SEND,
+			gtk_entry_get_text(GTK_ENTRY(wizard->smtp_password)),
+			FALSE);
+
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wizard->smtp_auth))) {
 		prefs_account->use_smtp_auth = TRUE;
 	}
@@ -793,13 +797,17 @@ static gboolean wizard_write_config(WizardWindow *wizard)
 
 	prefs_account->out_ssl_client_cert_file = g_strdup(
 				gtk_entry_get_text(GTK_ENTRY(wizard->smtp_ssl_cert_file)));
-	prefs_account->out_ssl_client_cert_pass = g_strdup(
-				gtk_entry_get_text(GTK_ENTRY(wizard->smtp_ssl_cert_pass)));
 	prefs_account->in_ssl_client_cert_file = g_strdup(
 				gtk_entry_get_text(GTK_ENTRY(wizard->recv_ssl_cert_file)));
-	prefs_account->in_ssl_client_cert_pass = g_strdup(
-				gtk_entry_get_text(GTK_ENTRY(wizard->recv_ssl_cert_pass)));
+
+	passwd_store_set_account(prefs_account->account_id, PWS_ACCOUNT_SEND_CERT,
+			gtk_entry_get_text(GTK_ENTRY(wizard->smtp_ssl_cert_pass)),
+			FALSE);
+	passwd_store_set_account(prefs_account->account_id, PWS_ACCOUNT_RECV_CERT,
+			gtk_entry_get_text(GTK_ENTRY(wizard->recv_ssl_cert_pass)),
+			FALSE);
 #endif
+
 	if (prefs_account->protocol == A_IMAP4) {
 		gchar *directory = gtk_editable_get_chars(
 			GTK_EDITABLE(wizard->recv_imap_subdir), 0, -1);
@@ -840,8 +848,7 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 
 	/* create the titlebar */
 	hbox = gtk_hbox_new (FALSE, 12);
-	image = stock_pixmap_widget(wizard->window, 
-			  	STOCK_PIXMAP_CLAWS_MAIL_ICON);
+	image = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_ICON);
 	gtk_box_pack_start (GTK_BOX(hbox), image, FALSE, FALSE, 0);
      	title_string = g_strconcat ("<span size=\"xx-large\" weight=\"ultrabold\">", title ? title : "", "</span>", NULL);
 	w = gtk_label_new (title_string);
@@ -1815,8 +1822,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Welcome to Claws Mail"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(wizard->window, 
-			  	STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
@@ -1898,8 +1904,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Configuration finished"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(wizard->window, 
-			  	STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
